package com.ruoyi.mall.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallCombineOrderLink;

/**
 * 拼团订单关联Mapper接口
 *
 * @author ruoyi
 * @date 2024-03-21
 */
public interface MallCombineOrderLinkMapper
{
    /**
     * 查询拼团订单关联
     *
     * @param linkId 拼团订单关联主键
     * @return 拼团订单关联
     */
    public MallCombineOrderLink selectMallCombineOrderLinkByLinkId(Long linkId);

    /**
     * 查询拼团订单关联列表
     *
     * @param mallCombineOrderLink 拼团订单关联
     * @return 拼团订单关联集合
     */
    public List<MallCombineOrderLink> selectMallCombineOrderLinkList(MallCombineOrderLink mallCombineOrderLink);

    /**
     * 新增拼团订单关联
     *
     * @param mallCombineOrderLink 拼团订单关联
     * @return 结果
     */
    public int insertMallCombineOrderLink(MallCombineOrderLink mallCombineOrderLink);

    /**
     * 修改拼团订单关联
     *
     * @param mallCombineOrderLink 拼团订单关联
     * @return 结果
     */
    public int updateMallCombineOrderLink(MallCombineOrderLink mallCombineOrderLink);

    /**
     * 删除拼团订单关联
     *
     * @param linkId 拼团订单关联主键
     * @return 结果
     */
    public int deleteMallCombineOrderLinkByLinkId(Long linkId);

    /**
     * 批量删除拼团订单关联
     *
     * @param linkIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallCombineOrderLinkByLinkIds(Long[] linkIds);

    /**
     * 待拼团列表
     *
     * @param params 参数
     * @return 待拼团列表
     */
    public List<Map<String, Object>> getWaitCombineList(Map<String, Object> params);

    /**
     * 待拼团详情
     *
     * @param params 参数
     * @return 待拼团详情
     */
    public Map<String, Object> getWaitCombineInfo(Map<String, Object> params);
}
